@@ -491,7 +491,7 @@ def _get_type_hint(autodoc_mock_imports: list[str], name: str, obj: Any) -> dict
     return result
 
 
-def backfill_type_hints(obj: Any, name: str) -> dict[str, Any]:  # noqa: C901, PLR0911, PLR0912
+def backfill_type_hints(obj: Any, name: str) -> dict[str, Any]:  # noqa: C901, PLR0911
     """
     Backfill type hints.
 
@@ -615,7 +615,7 @@ def format_default(app: Sphinx, default: Any, is_annotated: bool) -> str | None:
     return f"default: ``{formatted}``"
 
 
-def process_docstring(  # noqa: PLR0913, PLR0917, PLR0917
+def process_docstring(  # noqa: PLR0913, PLR0917
     app: Sphinx,
     what: str,
     name: str,
